Package: torchdatasets
Title: Ready to Use Extra Datasets for Torch
Version: 0.3.2
Authors@R: 
    c(
    person("Tomasz", "Kalinowski", role = c("ctb", "cre"), email = "tomasz@posit.co"),
    person("Daniel", "Falbel", role = c("aut", "cph"), email = "dfalbel@gmail.com"),
    person(family = "RStudio", role = c("cph"))
    )
Description: Provides datasets in a format that can be easily consumed by torch 'dataloaders'.
  Handles data downloading from multiple sources, caching and pre-processing so
  users can focus only on their model implementations.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: torch (>= 0.5.0), fs, zip, pins, torchvision, stringr, withr,
        utils
Suggests: testthat, readr, coro, tokenizers, R.matlab
URL: https://mlverse.github.io/torchdatasets/,
        https://github.com/mlverse/torchdatasets
BugReports: https://github.com/mlverse/torchdatasets/issues
NeedsCompilation: no
Packaged: 2026-04-28 16:21:17 UTC; dfalbel
Author: Tomasz Kalinowski [ctb, cre],
  Daniel Falbel [aut, cph],
  RStudio [cph]
Maintainer: Tomasz Kalinowski <tomasz@posit.co>
Repository: CRAN
Date/Publication: 2026-04-29 06:40:02 UTC
Built: R 4.4.3; ; 2026-05-01 14:02:45 UTC; unix
