# Generated by roxygen2: do not edit by hand

export(bank_marketing_dataset)
export(bird_species_dataset)
export(cityscapes_pix2pix_dataset)
export(dogs_vs_cats_dataset)
export(guess_the_correlation_dataset)
export(imdb_dataset)
export(oxford_flowers102_dataset)
export(oxford_pet_dataset)
export(spam_dataset)
importFrom(stringr,str_extract)
importFrom(torch,dataset)
importFrom(torchvision,base_loader)
